@@ -23,17 +23,20 @@
 
 import configparser
 import gettext
+
+
 from io import StringIO
 
-from otopi import common
 from otopi import constants as otopicons
+from otopi import common
 from otopi import plugin
 from otopi import util
 
+from ovirt_setup_lib import dialog
+
+from ovirt_hosted_engine_ha.lib import heconflib
 
 from ovirt_hosted_engine_setup import constants as ohostedcons
-from ovirt_setup_lib import dialog
-from ovirt_hosted_engine_ha.lib import heconflib
 
 
 def _(m):
@@ -132,27 +135,18 @@ class Plugin(plugin.PluginBase):
         name=ohostedcons.Stages.REQUIRE_ANSWER_FILE,
         stage=plugin.Stages.STAGE_CUSTOMIZATION,
         after=(
-            ohostedcons.Stages.DIALOG_TITLES_S_SYSTEM,
+            ohostedcons.Stages.DIALOG_TITLES_S_STORAGE,
             ohostedcons.Stages.CONFIG_STORAGE_LATE,
         ),
         before=(
-            ohostedcons.Stages.DIALOG_TITLES_E_SYSTEM,
+            ohostedcons.Stages.DIALOG_TITLES_E_STORAGE,
         ),
         condition=lambda self: (
-            self.environment[ohostedcons.CoreEnv.IS_ADDITIONAL_HOST] or
             self.environment[ohostedcons.CoreEnv.UPGRADING_APPLIANCE] or
             self.environment[ohostedcons.CoreEnv.ROLLBACK_UPGRADE]
         ),
     )
     def _customization(self):
-        if self.environment[ohostedcons.CoreEnv.IS_ADDITIONAL_HOST]:
-            self.logger.warning(
-                _(
-                    'A configuration file must be supplied to deploy '
-                    'Hosted Engine on an additional host.'
-                )
-            )
-
         if self.environment[
             ohostedcons.FirstHostEnv.SKIP_SHARED_STORAGE_ANSWERF
         ]:
@@ -187,7 +181,6 @@ class Plugin(plugin.PluginBase):
                 if self.environment[ohostedcons.CoreEnv.UPGRADING_APPLIANCE]:
                     self.environment[ohostedcons.VMEnv.OVF] = _ovf
                     self.environment[ohostedcons.VMEnv.CDROM] = None
-                    self.environment[ohostedcons.VMEnv.BOOT] = 'disk'
                     self.environment[
                         ohostedcons.CloudInit.GENERATE_ISO
                     ] = ohostedcons.Const.CLOUD_INIT_GENERATE
@@ -200,6 +193,9 @@ class Plugin(plugin.PluginBase):
                     self.environment[
                         ohostedcons.Upgrade.BACKUP_SIZE_GB
                     ] = self.environment[ohostedcons.StorageEnv.IMAGE_SIZE_GB]
+                    self.environment[
+                        ohostedcons.StorageEnv.IMAGE_SIZE_GB
+                    ] = None
             else:
                 self.logger.error(_(
                     'Unable to find the hosted-engine configuration volume '
